@@ -12,7 +12,7 @@
  *  Authors: Emily Sarneso
  *  ------------------------------------------------------------------------
  *  @DISTRIBUTION_STATEMENT_BEGIN@
- *  super_mediator-1.12
+ *  super_mediator-1.13
  *
  *  Copyright 2025 Carnegie Mellon University.
  *
@@ -35,7 +35,7 @@
  *  This Software includes and/or makes use of Third-Party Software each
  *  subject to its own license.
  *
- *  DM25-0935
+ *  DM25-1447
  *  @DISTRIBUTION_STATEMENT_END@
  *  ------------------------------------------------------------------------
  */
@@ -1111,7 +1111,7 @@ mdConfigureExporter(
         g_free(outspec);
 
         if (rotate > 0) {
-            mdExporterSetRotate(exporter, rotate);
+            mdExporterSetRotateSeconds(exporter, rotate);
         }
 
         /* The --fields command line option. */
@@ -1254,7 +1254,7 @@ mdConfigureExporter(
 
         mdExporterSetFileSpec(exporter, outspec);
         if (rotate > 0) {
-            mdExporterSetRotate(exporter, rotate);
+            mdExporterSetRotateSeconds(exporter, rotate);
         }
     }
 
