@@ -139,17 +139,20 @@
      TOK_SILKCONFIG_SENSOR = 355,
      TOK_SILKCONFIG_SILK = 356,
      TOK_TIME_UNITS = 357,
-     VAL_ATOM = 358,
-     VAL_DATETIME = 359,
-     VAL_DOUBLE = 360,
-     VAL_INTEGER = 361,
-     VAL_IP = 362,
-     VAL_QSTRING = 363,
-     VAL_TRANSPORT = 364,
-     VAL_OPER = 365,
-     VAL_FIELD = 366,
-     VAL_LOGLEVEL = 367,
-     VAL_TIMEUNIT = 368
+     TOK_ROTATE_MAX_SIZE = 358,
+     TOK_ROTATE_MIN_SIZE = 359,
+     VAL_ATOM = 360,
+     VAL_DATETIME = 361,
+     VAL_DOUBLE = 362,
+     VAL_HEXADECIMAL = 363,
+     VAL_INTEGER = 364,
+     VAL_IP = 365,
+     VAL_QSTRING = 366,
+     VAL_TRANSPORT = 367,
+     VAL_OPER = 368,
+     VAL_FIELD = 369,
+     VAL_LOGLEVEL = 370,
+     VAL_TIMEUNIT = 371
    };
 #endif
 /* Tokens.  */
@@ -253,24 +256,27 @@
 #define TOK_SILKCONFIG_SENSOR 355
 #define TOK_SILKCONFIG_SILK 356
 #define TOK_TIME_UNITS 357
-#define VAL_ATOM 358
-#define VAL_DATETIME 359
-#define VAL_DOUBLE 360
-#define VAL_INTEGER 361
-#define VAL_IP 362
-#define VAL_QSTRING 363
-#define VAL_TRANSPORT 364
-#define VAL_OPER 365
-#define VAL_FIELD 366
-#define VAL_LOGLEVEL 367
-#define VAL_TIMEUNIT 368
+#define TOK_ROTATE_MAX_SIZE 358
+#define TOK_ROTATE_MIN_SIZE 359
+#define VAL_ATOM 360
+#define VAL_DATETIME 361
+#define VAL_DOUBLE 362
+#define VAL_HEXADECIMAL 363
+#define VAL_INTEGER 364
+#define VAL_IP 365
+#define VAL_QSTRING 366
+#define VAL_TRANSPORT 367
+#define VAL_OPER 368
+#define VAL_FIELD 369
+#define VAL_LOGLEVEL 370
+#define VAL_TIMEUNIT 371
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 401 "mediator_config_parse.y"
+#line 409 "mediator_config_parse.y"
 {
     char                   *str;
     int                     integer;
@@ -283,7 +289,7 @@ typedef union YYSTYPE
     mdTimeUnits_t           timeUnit;
 }
 /* Line 1529 of yacc.c.  */
-#line 287 "mediator_config_parse.h"
+#line 293 "mediator_config_parse.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
